// InternetUpdate.h : Declaration of the CInternetUpdate

#ifndef __InternetUpdate_H_
#define __InternetUpdate_H_

#include <Wininet.h>
#include "Exception.h"

/////////////////////////////////////////////////////////////////////////////
// CInternetUpdate
// For updating or installing of an application or file

class CInternetUpdate 
{
public:
	//Constructor
	//
	//LPCTSTR lpszMessageBoxCaption - used for creating of messages and dialogs captions.
	//		For example, if lpszMessageBoxCaption = "Update Test" and you want to update the 1,0,0,1 version
	//		of the application, you can see a dialog with "Update Test 1,0,0,1 update" caption
	//
	//LPCTSTR lpszURL - FTP site address.
	//
	//LPCTSTR lpszDefaultInstallDirectory - Path to the folder on your hard drive,
	//		where an application will be updated or installed. This parameter is used only if
	//		key Directory=Default for current installed file section in the FileList.INI file,
	//		located in a FTP folder. For example you want to update the UpdateTest.exe applacation
	//		located in the "C:\MY DOCUMENTS\MYPROJECTS\UpdateTest\Debug\" directory from
	//		"ftp://comber-adsl.demon.co.uk/Updates/UpdateTest/1,0,0,2/" site.
	//		For it:
	//			1. Include Directory=Default key in the [UpdateTest.exe] section of the
	//					"ftp://comber-adsl.demon.co.uk/Updates/UpdateTest/1,0,0,2/FileList.INI" file.
	//			2. lpszDefaultInstallDirectory = "C:\MY DOCUMENTS\MYPROJECTS\UpdateTest\Debug\"
	//
	//LPCTSTR lpszTempFolder - Temporary folder for downloading all files from FTP folder before
	//		updating or installing
	//		For example if you want update UpdateTest.exe application from
	//		"ftp://comber-adsl.demon.co.uk/Updates/UpdateTest/1,0,0,2/" site and
	//		lpszTempFolder = "C:\My Documents\MyProjects\UpdateTest\Debug\Update",
	//		then all files from this site will be downloaded to
	//		"C:\My Documents\MyProjects\UpdateTest\Debug\Update" folder.
	//
	//BOOL boPromptNewestVersion
	//		TRUE - informs user about he use newest version. No necessary to update.
	//			User can return to old version in this case yet.
	//		FALSE - Nothing does if newest version is used. This mode is useful to updating in
	//			separate thread during starting of the application. See using of the CInternetUpdateEm
	//			class for details.
	CInternetUpdate(LPCTSTR lpszMessageBoxCaption, LPCTSTR lpszURL, LPCTSTR lpszDefaultInstallDirectory
			, LPCTSTR lpszTempFolder, BOOL boPromptNewestVersion = FALSE)
		: m_boPromptNewestVersion(boPromptNewestVersion)
		, m_strURL(lpszURL)
		, m_strDefaultInstallDirectory(lpszDefaultInstallDirectory)
		, m_strMessageBoxCaption(lpszMessageBoxCaption)
		, m_strTempFolder(lpszTempFolder)
	{
	}

	~CInternetUpdate()
	{
	}

	//Downloading and installing an application or file(s)
	//LPCTSTR lpszFolder - name of the folder with installation files in the current FTP site.
	//		For example if you want to install Microsoft Data Access Components 2.5
	//		from "ftp://comber-adsl.demon.co.uk/Updates/Em/MDAC/MDAC_TYP.EXE"
	//		and lpszURL = "ftp://comber-adsl.demon.co.uk/Updates/" (see CInternetUpdate constructor),
	//		then lpszFolder = "Em/MDAC"
	void DownloadAndInstall(LPCTSTR lpszFolder);

	void SetURL(LPCTSTR lpszURL)
		{ m_strURL = lpszURL; }

	//Updating to newest version or back to previous version
	//WORD wVersion1, WORD wVersion2, WORD wVersion3, WORD wVersion4 - application's version
	//		is used for comparison with version folder name. The version folder name have
	//		structure - <wVersion1>,<wVersion2>,<wVersion3>,<wVersion4>.
	//
	//    wVersion1 higher of the wVersion2
	//    wVersion2 higher of the wVersion4
	//    ATTENTION!!! wVersion4 higher of the wVersion3
	//
	//    For example your current application version is: 1,0,0,1
	//    The version, located in the "1,0,0,2" folder of the
	//		"ftp://comber-adsl.demon.co.uk/Updates/UpdateTest/" site is higher of the current version.
	//
	//		You can see a file version in the Version tab of the file Properties.
	//
	//		You can get file version by GetFileVersionInfo(...) function.
	//		See my GetFileVersion(...) function for example.
	virtual void Download(WORD wVersion1, WORD wVersion2, WORD wVersion3, WORD wVersion4);

protected:

	BOOL m_boPromptNewestVersion;//You use newest version. There is no necessity to update.

private:
	CString m_strURL;
	CString m_strDefaultInstallDirectory;
	CString m_strMessageBoxCaption;
	CString m_strTempFolder;
};

#endif //__InternetUpdate_H_
